==> apache-camel-3.10.0-src.zip: apache-camel-3.10.0/components/camel-ahc-ws/src/test/java/org/apache/camel/component/ahc/ws/WsProducerUsingStreamingTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.ahc.ws;

import java.io.UnsupportedEncodingException;

import org.eclipse.jetty.server.Connector;
import org.eclipse.jetty.server.ServerConnector;

public class WsProducerUsingStreamingTest extends WsProducerTestBase {

    @Override
    protected void setUpComponent() throws Exception {
    }

    @Override
    protected Connector getConnector() throws Exception {
        return new ServerConnector(server);
    }

    @Override
    protected String getTextTestMessage() {
        return super.getTextTestMessage();
    }

    @Override
    protected byte[] getByteTestMessage() throws UnsupportedEncodingException {
        return createLongByteTestMessage();
    }

    @Override
    protected String getTargetURL() {
        return "ahc-ws://localhost:" + PORT + "?useStreaming=true";
    }
}

==> apache-camel-3.18.3-src.zip: apache-camel-3.18.3/components/camel-ahc-ws/src/test/java/org/apache/camel/component/ahc/ws/WsProducerUsingStreamingTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.ahc.ws;

import org.eclipse.jetty.server.Connector;
import org.eclipse.jetty.server.ServerConnector;

public class WsProducerUsingStreamingTest extends WsProducerTestBase {

    @Override
    protected void setUpComponent() {
    }

    @Override
    protected Connector getConnector() {
        return new ServerConnector(server);
    }

    @Override
    protected String getTextTestMessage() {
        return super.getTextTestMessage();
    }

    @Override
    protected byte[] getByteTestMessage() {
        return createLongByteTestMessage();
    }

    @Override
    protected String getTargetURL() {
        return "ahc-ws://localhost:" + PORT + "?useStreaming=true";
    }
}
